Welcome to EPICS-sumo documentation! — Support Module Manager 3.7.1 documentation

# Welcome to EPICS-sumo documentation!

## A SUpport MOdule manager for EPICS

The support module manager sumo is a program to build consistent sets of EPICS support modules and use them in EPICS applications.

Some of the features are:

- All module dependencies are held in a JSON dependency database.
- The dependency database can be managed automatically with a version control system in order to keep it in sync on a number of build hosts.
- In order to migrate your existing support module installation a scanner program creates a dependency database from existing support directories.
- The program builds consistent sets of EPICS support modules.
- The program fetches module source code from various sources, directories, tar files or version control systems (currently git, mercurial, darcs, subversion and cvs).
- If a set of support modules is to be used in an application a RELEASE is generated with all the relevant paths.

See Introduction for more information.

Author: | Goetz Pfeiffer <Goetz.Pfeiffer@helmholtz-berlin.de>

## Documentation

### Reference documents

- sumo
- sumo-scan
- Configuration Files
- Module Specifications

### Use cases

- Using sumo in your application
- Example for sumo build try
- Develop support modules with sumo
- Migrating supports and applications

### Full list of documents

- Installing Sumo
- Introduction
- Module Specifications
- Configuration Files
- sumo-scan
- sumo
- Using sumo in your application
- Develop support modules with sumo
- Example for sumo build try
- Migrating supports and applications
- How to Contribute
- Glossary

## License and copyright

Copyright (c) 2020 by Helmholtz-Zentrum Berlin.

This software of this project can be used under GPL v.3, see SUMO license.

## Download

Sumo is available as a debian or rpm package, as tar.gz or zip here:

- sumo downloads at Sourceforge

## Install

You install sumo either as a debian or rpm package with your package manager, from source or with pip.

For details on how to install sumo see Installing Sumo.

## Sumo at sourceforge

You find the sourceforge summary page for sumo at epics-sumo at Sourceforge.

## The source

You can browse the mercurial repository here:

repository at Sourceforge.

or clone it with this command:

Sourceforge:

    hg clone http://hg.code.sf.net/p/epics-sumo/mercurial epics-sumo

## How to contribute

If you have bug fixes or changes and extensions of sumo you are encouraged to send my your changes. Here is a short description:

- How to Contribute

## Indices and tables

- Index
- Module Index
- Search Page